@@ -124,6 +124,12 @@ namespace Tomboy
 			if (NoteRenamed != null)
 				NoteRenamed (note, old_title);
 		}
+		
+		void OnNoteSave (Note note)
+		{
+			if (NoteSaved != null)
+				NoteSaved (note);
+		}
 
 		protected virtual void CreateStartNotes () 
 		{
@@ -142,7 +148,8 @@ namespace Tomboy
 						"your ideas and thoughts.\n\n" +
 						"You can create new notes to hold your ideas by " +
 						"selecting the \"Create New Note\" item from the " +
-						"Tomboy Notes menu in your GNOME Panel.\n\n" +
+						"Tomboy Notes menu in your GNOME Panel. " +
+						"Your note will be saved automatically.\n\n" +
 						"Then organize the notes you create by linking " +
 						"related notes and ideas together!\n\n" +
 						"We've created a note called " +
@@ -170,16 +177,17 @@ namespace Tomboy
 			try {
 				Note start_note = Create (Catalog.GetString ("Start Here"),
 								start_note_content);
-				start_note.Save ();
+				start_note.QueueSave (true);
 				Preferences.Set (Preferences.START_NOTE_URI, start_note.Uri);
 
 				Note links_note = Create (Catalog.GetString ("Using Links in Tomboy"),
 								links_note_content);
-				links_note.Save ();
+				links_note.QueueSave (true);
 				
 				start_note.Window.Show ();
-			} catch {
-				// Fail silently
+			} catch (Exception e) {
+				Logger.Warn ("Error creating start notes: {0}\n{1}",
+						e.Message, e.StackTrace);
 			}
 		}
 
@@ -192,6 +200,7 @@ namespace Tomboy
 					Note note = Note.Load (file_path, this);
 					if (note != null) {
 						note.Renamed += OnNoteRename;
+						note.Saved += OnNoteSave;
 						notes.Add (note);
 					}
 				} catch (System.Xml.XmlException e) {
@@ -352,6 +361,7 @@ namespace Tomboy
 			Note new_note = Note.CreateNewNote (title, filename, this);
 			new_note.XmlContent = xml_content;
 			new_note.Renamed += OnNoteRename;
+			new_note.Saved += OnNoteSave;
 
 			notes.Add (new_note);
 
@@ -430,6 +440,7 @@ namespace Tomboy
 		public event NotesChangedHandler NoteDeleted;
 		public event NotesChangedHandler NoteAdded;
 		public event NoteRenameHandler NoteRenamed;
+		public event NoteSavedHandler NoteSaved;
 	}
 
 	public class TrieController
